@@ -1243,13 +1243,6 @@ def show_first_line(context, textbox, text_overflow, block_ellipsis):
     pango.pango_layout_set_single_paragraph_mode(
         textbox.pango_layout.layout, True)
 
-    if text_overflow == 'ellipsis':
-        max_width = context.clip_extents()[2] - textbox.position_x
-        pango.pango_layout_set_width(
-            textbox.pango_layout.layout, units_from_double(max_width))
-        pango.pango_layout_set_ellipsize(
-            textbox.pango_layout.layout, pango.PANGO_ELLIPSIZE_END)
-
     if text_overflow == 'ellipsis' or block_ellipsis != 'none':
         max_width = context.clip_extents()[2] - textbox.position_x
         pango.pango_layout_set_width(
@@ -1263,7 +1256,17 @@ def show_first_line(context, textbox, text_overflow, block_ellipsis):
             else:
                 assert block_ellipsis[0] == 'string'
                 ellipsis = block_ellipsis[1]
-            textbox.pango_layout.set_text(textbox.pango_layout.text + ellipsis)
+
+            # Remove last word if hyphenated
+            new_text = textbox.pango_layout.text
+            if new_text.endswith(textbox.style['hyphenate_character']):
+                last_word_end = get_last_word_end(
+                    new_text[:-len(textbox.style['hyphenate_character'])],
+                    textbox.style['lang'])
+                if last_word_end:
+                    new_text = new_text[:last_word_end]
+
+            textbox.pango_layout.set_text(new_text + ellipsis)
 
     first_line, second_line = textbox.pango_layout.get_first_line()
 
@@ -1274,8 +1277,7 @@ def show_first_line(context, textbox, text_overflow, block_ellipsis):
                 textbox.style['lang'])
             if last_word_end is None:
                 break
-            new_text = utf8_slice(
-                textbox.pango_layout.text, slice(0, last_word_end))
+            new_text = textbox.pango_layout.text[:last_word_end]
             textbox.pango_layout.set_text(new_text + ellipsis)
             first_line, second_line = textbox.pango_layout.get_first_line()
 
@@ -1331,4 +1333,4 @@ def get_last_word_end(text, lang):
     bytestring, log_attrs = get_log_attrs(text, lang)
     for i, attr in enumerate(list(log_attrs)[::-1]):
         if i and attr.is_word_end:
-            return len(bytestring) - i
+            return len(text) - i
